@@ -28,25 +28,49 @@ def get_cell (lines) :
     blk = lines[idx:idx+2]
     ibrav = int(blk[0].replace(',','').split('=')[-1])
     if ibrav == 0:
+        for iline in lines:
+            if 'CELL_PARAMETERS' in iline and 'angstrom' not in iline.lower():
+                raise RuntimeError("CELL_PARAMETERS must be written in Angstrom. Other units are not supported yet.")
         blk = get_block(lines, 'CELL_PARAMETERS')
         for ii in blk:
             ret.append([float(jj) for jj in ii.split()[0:3]])
         ret = np.array(ret)
     elif ibrav == 1:
-        a = float(blk[1].split('=')[-1])
+        a = None
+        for iline in lines:
+            line = iline.replace("=", " ").replace(",", "").split()
+            if len(line) >= 2 and "a" == line[0]:
+                #print("line = ", line)
+                a = float(line[1])
+            if len(line) >= 2 and "celldm(1)" == line[0]:
+                a = float(line[1])*bohr2ang
+        #print("a = ", a)
+        if not a:
+            raise RuntimeError("parameter 'a' or 'celldm(1)' cannot be found.")
         ret = np.array([[a,0.,0.],[0.,a,0.],[0.,0.,a]])
     else:
         sys.exit('ibrav > 1 not supported yet.')
     return ret
 
-def get_coords (lines) :
+def get_coords (lines, cell) :
     coord = []
     atom_symbol_list = []
-    blk = get_block(lines, 'ATOMIC_POSITIONS')
-    for ii in blk:
-        coord.append([float(jj) for jj in ii.split()[1:4]])
-        atom_symbol_list.append(ii.split()[0])
-    coord = np.array(coord)
+    for iline in lines:
+        if 'ATOMIC_POSITIONS' in iline and ('angstrom' not in iline.lower() and 'crystal' not in iline.lower()):
+            raise RuntimeError("ATOMIC_POSITIONS must be written in Angstrom or crystal. Other units are not supported yet.")
+        if 'ATOMIC_POSITIONS' in iline and 'angstrom' in iline.lower():
+            blk = get_block(lines, 'ATOMIC_POSITIONS')
+            for ii in blk:
+                coord.append([float(jj) for jj in ii.split()[1:4]])
+                atom_symbol_list.append(ii.split()[0])
+            coord = np.array(coord)
+        elif 'ATOMIC_POSITIONS' in iline and 'crystal' in iline.lower():
+            blk = get_block(lines, 'ATOMIC_POSITIONS')
+            for ii in blk:
+                coord.append([float(jj) for jj in ii.split()[1:4]])
+                atom_symbol_list.append(ii.split()[0])
+            coord = np.array(coord)
+            coord = np.matmul(coord, cell.T)
     atom_symbol_list = np.array(atom_symbol_list)
     tmp_names, symbol_idx = np.unique(atom_symbol_list, return_index=True)
     atom_types = []
@@ -104,8 +128,8 @@ def get_frame (fname):
         outlines = fp.read().split('\n')
     with open(path_in, 'r') as fp:
         inlines = fp.read().split('\n')
-    atom_names, natoms, types, coords      = get_coords(inlines)
     cell        = get_cell  (inlines)
+    atom_names, natoms, types, coords      = get_coords(inlines, cell)
     energy      = get_energy(outlines)
     force       = get_force (outlines)
     stress      = get_stress(outlines) * np.linalg.det(cell)
