@@ -30,6 +30,15 @@ class TestMultiSystems(unittest.TestCase, CompLabeledSys, MultiSystems, IsNoPBC)
         self.system_sizes = {'C1H4':2, 'C1H3':1}
         self.atom_names = ['C', 'H']
 
+    def test_len(self):
+        self.assertEqual(len(self.systems), 2)
+
+    def test_get_nframes(self):
+        self.assertEqual(self.systems.get_nframes(), 3)
+
+    def test_str(self):
+        self.assertEqual(str(self.systems), "MultiSystems (2 systems containing 3 frames)")
+
 
 class TestMultiSystemsAdd(unittest.TestCase, CompLabeledSys, MultiSystems, IsNoPBC):
     def setUp(self):
@@ -117,5 +126,18 @@ class TestTypeMap(unittest.TestCase):
             self.assertEqual(type_map, systems.atom_names)
 
 
+class TestMultiSystemsTo(unittest.TestCase, MultiSystems):
+    def setUp(self):
+        # CH4 and O2
+        system_1 = dpdata.LabeledSystem('gaussian/methane.gaussianlog', fmt='gaussian/log')
+        system_2 = dpdata.LabeledSystem('gaussian/oxygen.gaussianlog', fmt='gaussian/log')
+        systems1 = dpdata.MultiSystems(system_1, system_2)
+        systems1.to_deepmd_npy("tmp.multi.to")
+        self.systems = dpdata.MultiSystems().from_deepmd_npy("tmp.multi.to")
+
+        self.system_names = ['C1H4O0', 'C0H0O2']
+        self.system_sizes = {'C1H4O0':1, 'C0H0O2':1}
+        self.atom_names = ['C', 'H', 'O']
+
 if __name__ == '__main__':
     unittest.main()
